Attribute VB_Name = "DIFFUS"

Public Function MAP_STEEL_DIFFUS(ByVal X As Double, ByVal T As Double, ByVal WDIFF As Double) As Double
    Dim DIF, W, PSI, THETA, ACTIV, DACTIV, DASH, SIGMA, A5 As Double
    Dim BOLTZ, HH, R As Double
'   '//DIF=DIFFUSIVITY OF CARBON IN AUSTENITE  in cm^2/s
'    '//IZ=COORDINATION OF INTERSTIAL SITE
'    '//PSI=COMPOSITION DEPENDENCE OF DIFFUSION COEFFICIENT
'    '//THETA=NO. C ATOMS/ NO. FE ATOMS
'    '//ACTIV=ACTIVITY OF CARBON IN AUSTENITE
'    '//R=GAS CONSTANT
'    '//X=MOLE FRACTION OF CARBON
'    '//T=ABSOLUTE TEMPERATURE
'    '//SIGMA=SITE EXCLUSION PROBABLITY
'    '//W=CARBON-CARBON INTERACTION ENERGY IN AUSTENITE
    Dim IZ As Integer
    IZ = 12
    A5 = 1#
    BOLTZ = 1.380650524E-23 ''//8.615e-5
    W = WDIFF
    HH = 6.626176E-34
    R = 8.31441
    
    DASH = (BOLTZ * T / HH) * Exp(-(21230# / T)) * Exp(-31.84)
    THETA = X / (A5 - X)
    ACTIV = MAP_STEEL_CG(X, T, W, R)
    ACTIV = Exp(ACTIV)
    DACTIV = MAP_STEEL_DCG(X, T, W, R)
    DACTIV = DACTIV * ACTIV
    DACTIV = DACTIV * A5 / ((A5 + THETA) ^ 2)
    SIGMA = A5 - Exp((-(W)) / (R * T))
    PSI = ACTIV * (A5 + IZ * ((A5 + THETA) / (A5 - (A5 + IZ / 2) * THETA + (IZ / 2) * (A5 + IZ / 2) * (A5 - SIGMA) * THETA * THETA))) + (A5 + THETA) * DACTIV
    DIF = DASH * PSI
    MAP_STEEL_DIFFUS = DIF
    
End Function

Public Function MAP_STEEL_CG(ByVal X As Double, ByVal T As Double, ByVal W As Double, ByVal R As Double) As Double
    Dim AJ, DG, EG As Double
    AJ = 1# - Exp(-W / (R * T))
    If (X <= 0.0000000001) Then
            MAP_STEEL_CG = Log(0.0000000001)
    Else
        DG = Sqr(1# - 2# * (1# + 2# * AJ) * X + (1# + 8# * AJ) * X * X)
        EG = 5# * Log((1# - 2# * X) / X) + 6# * W / (R * T) + (38575# - 13.48 * T) / (R * T)
        MAP_STEEL_CG = EG + 6# * Log((DG - 1 + 3 * X) / (DG + 1 - 3 * X)) '  '// return this value,
    End If
End Function

Public Function MAP_STEEL_DCG(ByVal X As Double, ByVal T As Double, ByVal W As Double, ByVal R As Double) As Double
    Dim AJ, DG, DDG As Double
    AJ = 1# - Exp(-W / (R * T))
    DG = Sqr(1# - 2# * (1# + 2# * AJ) * X + (1# + 8# * AJ) * X * X)
    DDG = (0.5 / DG) * (-2# - 4# * AJ + 2# * X + 16# * AJ * X)
    MAP_STEEL_DCG = -((10# / (1# - 2# * X)) + (5# / X)) + 6# * ((DDG + 3#) / (DG - 1# + 3# * X) - (DDG - 3#) / (DG + 1# - 3# * X))
End Function

Public Function MAP_STEEL_OMEGA(ByRef C() As Double, ByRef X) As Double
    Dim B1, B2, B3, T10, T20, W, XBAR As Double
      Dim D(12), P(12), Y(12) As Double
    
      Dim i, IU, ID As Integer
      ID = 0
      B3 = 0#
      If (ID >= 2) Then GoTo A_110

      D(11) = C(0) + C(1) + C(2) + C(3) + C(4) + C(5) + C(6) + C(7) + C(8) + C(9) + C(10)
      D(11) = 100# - D(11)
      D(11) = D(11) / 55.84
      D(0) = C(0) / 12.0115
      D(1) = C(1) / 28.09
      D(2) = C(2) / 54.94
      D(3) = C(3) / 58.71
      D(4) = C(4) / 95.94
      D(5) = C(5) / 52#
      D(6) = C(6) / 50.94
      D(7) = C(7) / 58.94
      D(8) = C(8) / 63.54
      D(9) = C(9) / 26.98
      D(10) = C(10) / 183.85
      B1 = D(0) + D(1) + D(2) + D(3) + D(4) + D(5) + D(6) + D(7) + D(8) + D(9) + D(10) + D(11)
'//------------------------
      For IU = 0 To 11
         D(IU) = D(IU) / B1  '//change to molar fraction
      Next IU
      
'//------------------------
A_110:  For IU = 1 To 10
         Y(IU) = D(IU) / D(11)
         Next IU
         
      XBAR = D(0)
      XBAR = (10000# * XBAR)
      XBAR = XBAR / 10000
      X = XBAR
'/*------------------------------------------------------------------------------
'     Delta T_nm and Delta T_mag were taken for Co from
'     Aaronson, Pound and Domain work - Trans.Met.Soc. AIME,
'     Vol.236 May, 1966, p. 769   (S. Babu, 18.7.1989)
'     C    SI   MN   NI   MO   CR   V    CO   CU   AL    W      FE
'     1    2    3    4    5    6    7    8    9    10    11     12
'//------------------------------------------------------------------------------*/
      T10 = Y(1) * (-3) + Y(2) * 2 + Y(3) * 12 + Y(4) * (-9) + Y(5) * (-1) + Y(6) * (-12) + Y(7) * 3.5 + Y(8) * 7 + Y(9) * (-7) + Y(10) * (-9)
     
'//     T10 coefficients are actually Delt_mag - DelT_non.mag
'//     T20 coefficients are actually Delt_mag
      T20 = -3 * Y(1) - 37.5 * Y(2) - 6 * Y(3) - 26 * Y(4) - 19 * Y(5) - 44 * Y(6) + 19.5 * Y(7) - 4.5 * Y(8) + 8 * Y(9) - 26 * Y(10)
'//------------------------------------------------------------------------------
      P(1) = 2013.0341 + 763.8167 * D(1) + 45802.87 * D(1) ^ 2 - 280061.63 * D(1) ^ 3 + 3864000# * D(1) ^ 4 - 24233000# * D(1) ^ 5 + 69547000# * D(1) ^ 6
      P(2) = 2012.067 - 1764.095 * D(2) + 6287.52 * D(2) ^ 2 - 21647.96 * D(2) ^ 3 - 2011900# * D(2) ^ 4 + 31716000# * D(2) ^ 5 - 138850000# * D(2) ^ 6
      P(3) = 2006.8017 + 2330.2424 * D(3) - 54915.32 * D(3) ^ 2 + 1621600# * D(3) ^ 3 - 24968000# * D(3) ^ 4 + 188380000# * D(3) ^ 5 - 555310000# * D(3) ^ 6
      P(4) = 2006.834 - 2997.314 * D(4) - 37906.61 * D(4) ^ 2 + 1032800# * D(4) ^ 3 - 13306000# * D(4) ^ 4 + 84110000# * D(4) ^ 5 - 208260000# * D(4) ^ 6
      P(5) = 2012.367 - 9224.2655 * D(5) + 33657.8 * D(5) ^ 2 - 566827.83 * D(5) ^ 3 + 8567600# * D(5) ^ 4 - 67482000# * D(5) ^ 5 + 208370000# * D(5) ^ 6
      P(6) = 2011.9996 - 6247.9118 * D(6) + 5411.7566 * D(6) ^ 2 + 250118.1085 * D(6) ^ 3 - 4167600# * D(6) ^ 4
'/*------------------------------------------------------------------------------
'     CO  CU   AL    W      FE
'     8   9    10    11     12
'     EFFECT TAKEN FROM HKDB - MET.SCI - 1981
'     RESULT IN J/MOLE    (S. Babu, 18.7.1989)
'     W SAME AS MOLYBDENUM  IN INTERACION ENERGY
'//------------------------------------------------------------------------------*/
      P(7) = (8427# + 5986 * D(7)) / 4.187
      P(8) = 2011#
      P(9) = 2011#
      P(10) = 2006.834 - 2997.314 * D(10) - 37906.61 * D(10) ^ 2 + 1032800# * D(10) ^ 3 - 13306000# * D(10) ^ 4 + 84110000# * D(10) ^ 5 - 208260000# * D(10) ^ 6
      B2 = 0#
      
      For IU = 1 To 10
        B3 = B3 + P(IU) * Y(IU)
         B2 = B2 + Y(IU)
      Next IU
      
      If Abs(B2) < 1E-40 Then
         W = 8054#
      Else
         W = (B3 / B2) * 4.187
      End If
      
      If Abs(B3) < 1E-40 Then
         W = 8054#
      End If
      
      For IU = 0 To 11
         C(IU) = D(IU)
      Next IU
      
      MAP_STEEL_OMEGA = W
End Function

