Attribute VB_Name = "Driving_Force"
 Const NA = 6.0221415 * 10 ^ 23 'Avogadro's number
 Const Delta_C = 0.01
 'driving force per atom
Public Function DrivingForce(ByVal T As Double, ByRef Composition() As Double)

    ' demonstration of the MTDATA Application Interface
    'string for component/phase/species name
    Dim PhaseName As String * 50
    Dim name As String * 50
    Dim pvar As String * 10
    Dim count As Long
    
    Dim X_ab As Double
    Dim X_ba As Double
    
    
    'set system composition
    For count = 1 To INIT_NO_OF_COMPONENTS()
        Call SET_INIT_COMPONENT_MASS(count, Composition(count))
    Next
    
    
    Dim CCPT As Long
    
    CCPT = INIT_COMPONENT_NO("C", Len("C"))
    '--------------------------------------
    'classify component
    
    For i = 1 To INIT_NO_OF_COMPONENTS()
        If (i <> CCPT) Then
           Call SET_INIT_COMPONENT_CLASS(i, PARA) 'NORMAL)
        End If
    Next
    
    'set appropriate pressure /Pa and temperature in Kelvin
    Call SET_PRESSURE(101325#)
    Call SET_TEMPERATURE(T)
    
    
    '========================================
    'for austenite
    '----------------------------------
    'classify phases
    Dim NPHASE1, NPHASE2 As Long
    
    For count = 1 To INIT_NO_OF_PHASES()
        Call INIT_PHASE_NAME(name, 50, count)

        If (Trim(name) = "FCC_A1") Then
            Call SET_INIT_PHASE_CLASS(count, NORMAL)
        Else
           Call SET_INIT_PHASE_CLASS(count, ABSENT)
        End If
    Next
    
    
    Dim G_austenite(1 To 2) As Double
    Dim X_C(1 To 2) As Double
    Dim Austenite_Mole As Double
    Dim C_number As Long
    Dim W_C(1 To 2) As Double
    
    For i = 1 To 2
        If i = 1 Then
            Composition(1) = Composition(1) - Delta_C
        ElseIf i = 2 Then
            Composition(1) = Composition(1) + Delta_C
        End If
       
        Composition(11) = 100 - (Composition(1) + Composition(2) + Composition(3) + Composition(4) + _
        Composition(5) + Composition(6) + Composition(7) + Composition(8) + Composition(9) + Composition(10))
        
        'set composition
        For count = 1 To INIT_NO_OF_COMPONENTS()
            Call SET_INIT_COMPONENT_MASS(count, Composition(count))
        Next count
    
        
        'do the calculation
        Call COMPUTE_EQUILIBRIUM
        
        W_C(i) = Composition(1)
        
        NPHASE1 = ACT_PHASE_NO("FCC_A1", Len("FCC_A1"))
        C_number = ACT_COMPONENT_NO("C", Len("C"))
        X_C(i) = COMPONENT_X_OF_PHASE(C_number, NPHASE1, ACTIVE)
        
        Austenite_Mole = SUM_OF_COMPONENT_AMOUNT - INIT_COMPONENT_MOLES(1) - INIT_COMPONENT_MOLES(8) 'exclude interstitial element
        
        G_austenite(i) = GIBBS_ENERGY_OF_PHASE(NPHASE1) / Austenite_Mole / NA   'Gibbs energy of atom in austenite
    
    Next i
    
    
    '=============================================================
    ' for cementite
    
    
    For i = 1 To INIT_NO_OF_COMPONENTS()
        Call SET_INIT_COMPONENT_CLASS(i, NORMAL)
    Next
    
    For count = 1 To INIT_NO_OF_COMPONENTS()
        If count = 1 Then
            Call SET_INIT_COMPONENT_AMOUNT(count, 1)
        ElseIf count = 11 Then
            Call SET_INIT_COMPONENT_AMOUNT(count, 3)
        Else
            Call SET_INIT_COMPONENT_AMOUNT(count, 0)
            Call SET_INIT_COMPONENT_CLASS(i, ABSENT)
        End If
    Next
    
    
    For count = 1 To INIT_NO_OF_PHASES()
        Call INIT_PHASE_NAME(name, 50, count)
        
        If (Trim(name) = "CEMENTITE") Then
            Call SET_INIT_PHASE_CLASS(count, NORMAL)
        Else
           Call SET_INIT_PHASE_CLASS(count, ABSENT)
        End If
    Next
    
    Call COMPUTE_EQUILIBRIUM
    
    NPHASE2 = ACT_PHASE_NO("CEMENTITE", Len("CEMENTITE"))
    
    Dim G_cementite As Double
    
    G_cementite = GIBBS_ENERGY_OF_PHASE(NPHASE2) / 3 / NA
    
    DrivingForce = G_cementite - 6.67 * (G_austenite(2) - G_austenite(1)) / Delta_C
    
    
    If (NUMBER_OF_ERRORS() <> 0) Then
        'error found during calculation.
        'clear error flag, write out the error
        MsgBox ("Error in calculation")
        Call WRITE_ERROR
    End If


End Function

Public Function CEMENTITE(ByRef Composition() As Double, ByVal Temp As Double, ByRef CMT_V_f As Double)
    Dim name As String * 50
    Dim pvar As String * 10
    Dim count As Long
    
    Dim N_FCC As Long   'phase number in active phase list
    Dim N_BCC As Long
    Dim N_CEMENTITE As Long
    
    Dim Vol_f_FCC As Double   'volume fraction of phase
    Dim Vol_f_BCC As Double
    Dim Vol_f_CEMENTITE As Double
    Dim total_Vol As Double
    
    'set system composition
    For count = 1 To INIT_NO_OF_COMPONENTS()
        Call SET_INIT_COMPONENT_MASS(count, Composition(count))
    Next
    
    Dim CCPT As Long
    
    CCPT = INIT_COMPONENT_NO("C", Len("C"))
    
    'set appropriate pressure /Pa and temperature in Kelvin
    Call SET_PRESSURE(101325#)
    Call SET_TEMPERATURE(Temp)
    
    '----------------------------------
    'classify phases
    For count = 1 To INIT_NO_OF_PHASES()
        Call INIT_PHASE_NAME(name, 50, count)
        If (Trim(name) = "BCC_A2") Then
            Call SET_INIT_PHASE_CLASS(count, NORMAL)
        ElseIf (Trim(name) = "FCC_A1") Then
            Call SET_INIT_PHASE_CLASS(count, NORMAL)
        ElseIf (Trim(name) = "CEMENTITE") Then
            Call SET_INIT_PHASE_CLASS(count, NORMAL)
        Else
            Call SET_INIT_PHASE_CLASS(count, ABSENT)
        End If
    Next
    
    'classify components
    For i = 1 To INIT_NO_OF_COMPONENTS()
        Call SET_INIT_COMPONENT_CLASS(i, NORMAL)
    Next i
    
    Call COMPUTE_EQUILIBRIUM
    
     If (NUMBER_OF_ERRORS() <> 0) Then
        'error found during calculation.
        'clear error flag, write out the error
        MsgBox ("Error in calculation")
        Call WRITE_ERROR
    End If
    
    N_CEMENTITE = INIT_PHASE_NO("CEMENTITE", Len("CEMENTITE"))
    N_FCC = INIT_PHASE_NO("FCC_A1", Len("FCC_A1"))
    N_BCC = INIT_PHASE_NO("BCC_A2", Len("BCC_A2"))
    

    Vol_f_FCC = MASS_IN_PHASE(N_FCC, INITIAL) * 11.47 ' / SYSTEM_VOLUME
    Vol_f_BCC = MASS_IN_PHASE(N_BCC, INITIAL) * 11.77 '/ SYSTEM_VOLUME
    Vol_f_CEMENTITE = MASS_IN_PHASE(N_CEMENTITE, INITIAL) * 12.93 '/ SYSTEM_VOLUME
  
    CMT_V_f = Vol_f_CEMENTITE / (Vol_f_FCC + Vol_f_BCC + Vol_f_CEMENTITE)
    x = COMPONENT_W_OF_PHASE(11, N_FCC, INITIAL)
    
   ' Debug.Print Vol_f_FCC, Vol_f_BCC, Vol_f_CEMENTITE
    
   
    
    
    
End Function
