Attribute VB_Name = "mtdata"
'
' MTDATA SOURCE CODE:
'
'
'                  (c) National Physical Laboratory 2000
'
'#################################################################
'
' MTDATA Visual Basic Module
'
' Contains Subroutine, Function and Constant definitions
' for use with MTDATA DLL
'
' $Header: /mtdata/code/mtdata.bas 9     22/01/04 17:35 Jajr $
'
' $History: mtdata.bas $
'
' *****************  Version 9  *****************
' User: Jajr         Date: 22/01/04   Time: 17:35
' Updated in $/mtdata/code
' Added declarations for some more functions
' COMPONENT_MOLES_IN_PHASE
' MOLES_OF_COMPONENTS_IN_PHASE
' COMPONENT_FRACTION_IN_PHASE
' COMPONENT_X_OF_PHASE
' COMPONENT_W_OF_PHASE
'
' *****************  Version 7  *****************
' User: Jajr         Date: 31/05/00   Time: 11:13
' Updated in $/mtdata/dll
' added aliases for 4 routines to match changes in dll export list
'
' *****************  Version 5  *****************
' User: Jajr         Date: 7/03/00    Time: 17:45
' Updated in $/mtdata/dll
' added definition of new function mtdata_file_check
'
' *****************  Version 4  *****************
' User: Jajr         Date: 29/02/00   Time: 17:39
' Updated in $/mtdata/dll
' removed reference to initialise_mtdata and changed initialise_dll to
' initialise_mtdata_dll
'
' *****************  Version 3  *****************
' User: Jajr         Date: 15/02/00   Time: 11:18
' Updated in $/mtdata/dll
' Updated copyright date
'
' *****************  Version 2  *****************
' User: Jajr         Date: 15/02/00   Time: 11:12
' Updated in $/mtdata/dll
' Added declaration for COMPONENT_MASS_IN_PHASE
'
' *****************  Version 1  *****************
' User: Jajr         Date: 15/02/00   Time: 11:05
' Created in $/mtdata/dll
' 1st checked in version of MTDATA DLL routine declaration file
'
'#################################################################
'
' MTDATA Constants

Public Const ABSENT As Long = 0
Public Const NORMAL As Long = 1
Public Const FREE As Long = -1
Public Const PARA As Long = 3
Public Const MISC_1 As Long = -1
Public Const MISC_2 As Long = -2

Public Const MINIMAL As Long = -2
Public Const BRIEF As Long = -1
Public Const DEFAULT As Long = 0
Public Const MOLE_TABLE As Long = 19
Public Const WEIGHT_TABLE As Long = 29
Public Const PHASE_TABLE As Long = 9

Public Const BOTH_LARGE As Long = 0
Public Const ONE_ONLY  As Long = 1
Public Const TWO_ONLY As Long = 2
Public Const BOTH_SMALL  As Long = 3
Public Const ROBUST As Long = 4
Public Const ONE_PLUS As Long = 5
      
Public Const READ_IN As Long = 0
Public Const AUTO As Long = 1
Public Const PREVIOUS  As Long = 2
Public Const LOWER As Long = 3
Public Const LAST As Long = 4
      
Public Const INITIAL  As Long = 1
Public Const ACTIVE  As Long = 2


'##############################################################
'
' Routines to open mpi file and get details of contents
'    and details of system set

Public Declare Sub OPEN_MPI_FILE Lib "mtdata.dll" (ByVal mpiName As String, ByVal mpiNameLen As Long, ByVal mprName As String, ByVal mprNameLen As Long, ByRef ErrFlag As Long)

' system
Public Declare Function MASS_OF_SYSTEM Lib "mtdata.dll" () As Double
Public Declare Function MOLES_OF_SYSTEM Lib "mtdata.dll" () As Double
Public Declare Function SUM_OF_COMPONENT_MASS Lib "mtdata.dll" () As Double
Public Declare Function SUM_OF_COMPONENT_AMOUNT Lib "mtdata.dll" () As Double
Public Declare Function Temperature Lib "mtdata.dll" Alias "TEMPERATURE" () As Double
Public Declare Function PRESSURE Lib "mtdata.dll" () As Double

' components
Public Declare Function INIT_NO_OF_COMPONENTS Lib "mtdata.dll" () As Long
Public Declare Function INIT_COMPONENT_NO Lib "mtdata.dll" (ByVal CompName As String, ByVal CompNameLen As Long) As Long
Public Declare Sub INIT_COMPONENT_NAME Lib "mtdata.dll" (ByVal CompName As String, ByVal CompNameLen As Long, ByRef CompNum As Long)
Public Declare Function INIT_COMPONENT_CLASS Lib "mtdata.dll" (ByRef CompNum As Long) As Long
Public Declare Function INIT_COMPONENT_MOLES Lib "mtdata.dll" (ByRef CompNum As Long) As Double
Public Declare Function INIT_COMPONENT_MASS Lib "mtdata.dll" (ByRef CompNum As Long) As Double

Public Declare Function ACT_NO_OF_COMPONENTS Lib "mtdata.dll" () As Long
Public Declare Function ACT_COMPONENT_NO Lib "mtdata.dll" (ByVal CompName As String, ByVal CompNameLen As Long) As Long
Public Declare Sub ACT_COMPONENT_NAME Lib "mtdata.dll" (ByVal CompName As String, ByVal CompNameLen As Long, ByRef CompNum As Long)
Public Declare Function ACT_COMPONENT_CLASS Lib "mtdata.dll" (ByRef CompNum As Long) As Long
Public Declare Function ACT_COMPONENT_MOLES Lib "mtdata.dll" (ByRef CompNum As Long) As Double
Public Declare Function ACT_COMPONENT_MASS Lib "mtdata.dll" (ByRef CompNum As Long) As Double

' phases
Public Declare Function INIT_NO_OF_PHASES Lib "mtdata.dll" () As Long
Public Declare Function INIT_PHASE_NO Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long) As Long
Public Declare Sub INIT_PHASE_NAME Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long, ByRef PhaseNum As Long)
Public Declare Function INIT_PHASE_CLASS Lib "mtdata.dll" (ByRef PhaseNum As Long) As Long

Public Declare Function ACT_NO_OF_PHASES Lib "mtdata.dll" () As Long
Public Declare Function ACT_PHASE_NO Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long) As Long
Public Declare Sub ACT_PHASE_NAME Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long, ByRef PhaseNum As Long)
Public Declare Function ACT_PHASE_CLASS Lib "mtdata.dll" (ByRef PhaseNum As Long) As Long

' species
Public Declare Function INIT_NO_OF_SPECIES Lib "mtdata.dll" () As Long
Public Declare Function INIT_SPECIES_NO Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long) As Long
Public Declare Sub INIT_SPECIES_NAME Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long, ByRef SpeciesNum As Long)
Public Declare Function INIT_SPECIES_CLASS Lib "mtdata.dll" (ByRef SpeciesNum As Long) As Long

Public Declare Function ACT_NO_OF_SPECIES Lib "mtdata.dll" () As Long
Public Declare Function ACT_SPECIES_NO Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long) As Long
Public Declare Sub ACT_SPECIES_NAME Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long, ByRef SpeciesNum As Long)
Public Declare Function ACT_SPECIES_CLASS Lib "mtdata.dll" (ByRef SpeciesNum As Long) As Long


'#############################################################
'
' Routines to setup and perform a calculation

Public Declare Sub SET_INIT_COMPONENT_AMOUNT Lib "mtdata.dll" (ByRef CompNum As Long, ByRef amount As Double)
Public Declare Sub SET_INIT_COMPONENT_MASS Lib "mtdata.dll" (ByRef CompNum As Long, ByRef Mass As Double)
Public Declare Sub SET_INIT_COMPONENT_CLASS Lib "mtdata.dll" (ByRef CompNum As Long, ByRef Class As Long)

Public Declare Sub SET_INIT_PHASE_CLASS Lib "mtdata.dll" (ByRef PhaseNum As Long, ByRef Class As Long)

Public Declare Sub SET_INIT_SPECIES_CLASS Lib "mtdata.dll" (ByRef SpeciesNum As Long, ByRef Class As Long)

Public Declare Sub SET_TEMPERATURE Lib "mtdata.dll" (ByRef Temperature As Double)
Public Declare Sub SET_PRESSURE Lib "mtdata.dll" (ByRef PRESSURE As Double)
Public Declare Sub SET_VOLUME_OF_GAS Lib "mtdata.dll" (ByRef GasVolume As Double)
Public Declare Sub SET_SYSTEM_AMOUNT Lib "mtdata.dll" (ByRef SystemAmount As Double)
Public Declare Sub SET_SYSTEM_WEIGHT Lib "mtdata.dll" (ByRef SystemWeight As Double)

Public Declare Sub SET_INIT_POINT_OPTION Lib "mtdata.dll" (ByRef InitPoint As Long)
Public Declare Function INIT_POINT_OPTION Lib "mtdata.dll" () As Long
Public Declare Sub SET_STAGES_REQUIRED Lib "mtdata.dll" (ByRef StagesRequired As Long)
Public Declare Function STAGES_REQUIRED Lib "mtdata.dll" () As Long
Public Declare Sub SET_PRINT_LEVEL Lib "mtdata.dll" (ByRef PrintLevel As Long)
Public Declare Function PRINT_LEVEL Lib "mtdata.dll" () As Long

Public Declare Sub COMPUTE_EQUILIBRIUM Lib "mtdata.dll" ()

Public Declare Sub COMPUTE_BOUNDARY_TEMPERATURE Lib "mtdata.dll" (ByRef TMin As Double, ByRef TMax As Double, ByRef TAcc As Double, _
                                                    ByRef NumBoundaries As Long, ByRef HighTempPhaseNum As Long, ByRef PCent As Double, _
                                                    ByRef Mass1 As Double, ByRef Mass2 As Double, ByRef IFLAG As Long, ByRef IFail As Long)
Public Declare Function PHASE_BOUNDARY_TEMPERATURE Lib "mtdata.dll" (ByRef BoundaryNumber As Long) As Double
Public Declare Function NO_OF_PHASE_FIELDS Lib "mtdata.dll" () As Long
Public Declare Function BOUNDARY_NO_OF_PHASES Lib "mtdata.dll" (ByRef FieldNumber As Long) As Long
Public Declare Function BOUNDARY_PHASE_NO Lib "mtdata.dll" (ByRef PhaseNumber As Long, ByRef FieldNumber As Long) As Long


'#############################################################
'
' Routines to examine calculation results

Public Declare Function EQUIL_NO_OF_PHASES Lib "mtdata.dll" () As Long
Public Declare Function EQUIL_NO_OF_SPECIES Lib "mtdata.dll" () As Long

Public Declare Sub EQUIL_PHASE_NAME Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long, ByRef PhaseNum As Long)
Public Declare Function EQUIL_PHASE_NO Lib "mtdata.dll" (ByVal PhaseName As String, ByVal PhaseNameLen As Long) As Long
Public Declare Sub EQUIL_SPECIES_NAME Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long, ByRef SpeciesNum As Long)
Public Declare Function PHASE_PRESENT_AT_EQUILIBRIUM Lib "mtdata.dll" (ByRef EquilPhaseNum As Long) As Long

Public Declare Function SPECIES_MOLES_IN_SYSTEM Lib "mtdata.dll" (ByRef SpeciesNum As Long, ByRef ErrFlag As Long) As Double
Public Declare Function SPECIES_MASS_IN_SYSTEM Lib "mtdata.dll" (ByRef SpeciesNum As Long, ByRef ErrFlag As Long) As Double
Public Declare Function SPECIES_MOLES_IN_PHASE Lib "mtdata.dll" (ByRef SpeciesNum As Long, ByRef PhaseNum As Long, ByRef ErrFlag As Long) As Double
Public Declare Function SPECIES_MASS_IN_PHASE Lib "mtdata.dll" (ByRef SpeciesNum As Long, ByRef PhaseNum As Long, ByRef ErrFlag As Long) As Double

Public Declare Function COMPONENT_MASS_IN_PHASE Lib "mtdata.dll" (ByRef CompNum As Long, ByRef PhaseNum As Long, ByRef ListType As Long) As Double
Public Declare Function COMPONENT_MOLES_IN_PHASE Lib "mtdata.dll" (ByRef CompNum As Long, ByRef PhaseNum As Long, ByRef ListType As Long) As Double
Public Declare Function MOLES_OF_COMPONENTS_IN_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long, ByRef ListType As Long) As Double
Public Declare Function MASS_IN_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long, ByRef PhaseList As Long) As Double
Public Declare Function COMPONENT_FRACTION_IN_PHASE Lib "mtdata.dll" (ByRef CompNum As Long, ByRef PhaseNum As Long, ByRef ListType As Long) As Double
Public Declare Function COMPONENT_X_OF_PHASE Lib "mtdata.dll" (ByRef CompNum As Long, ByRef PhaseNum As Long, ByRef ListType As Long) As Double
Public Declare Function COMPONENT_W_OF_PHASE Lib "mtdata.dll" (ByRef CompNum As Long, ByRef PhaseNum As Long, ByRef ListType As Long) As Double

Public Declare Function SYSTEM_GIBBS_ENERGY Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_ENTHALPY Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_ENTROPY Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_VOLUME Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_INTERNAL_ENERGY Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_HELMHOLTZ_ENERGY Lib "mtdata.dll" () As Double
Public Declare Function SYSTEM_CP Lib "mtdata.dll" () As Double
' Public Declare Function SYSTEM_CV Lib "mtdata.dll" () As Double

Public Declare Function PARTIAL_SYSTEM_GIBBS_ENERGY Lib "mtdata.dll" (ByRef CompNum As Long) As Double
' Public Declare Function PARTIAL_SYSTEM_ENTHALPY Lib "mtdata.dll" (ByRef CompNum As Long) As Double
' Public Declare Function PARTIAL_SYSTEM_ENTROPY Lib "mtdata.dll" (ByRef CompNum As Long) As Double
' Public Declare Function COMPONENT_ACTIVITY Lib "mtdata.dll" (ByRef CompNum As Long) As Double

Public Declare Function GIBBS_ENERGY_OF_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long) As Double
Public Declare Function ENTHALPY_OF_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long) As Double
Public Declare Function ENTROPY_OF_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long) As Double
Public Declare Function PARTIAL_PRESSURE Lib "mtdata.dll" (ByVal SpeciesName As String, ByVal SpeciesNameLen As Long) As Double
Public Declare Function VOLUME_OF_GAS Lib "mtdata.dll" () As Double
Public Declare Function VOLUME_OF_PHASE Lib "mtdata.dll" (ByRef PhaseNum As Long) As Double



'#############################################################
'
' Functions used for searching databases

Public Declare Function MT_NO_AVAILABLE_DBASES Lib "mtdata.dll" () As Long
Public Declare Function MT_QUERY_AVAILABLE_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long) As Long
Public Declare Sub MT_TITLE_AVAILABLE_DBASE Lib "mtdata.dll" (ByVal DBTitle As String, ByVal DBTitleLen As Long, ByRef DBNum As Long)
Public Declare Sub MT_NAME_AVAILABLE_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long, ByRef DBNum As Long)
Public Declare Sub MT_ADD_AVAILABLE_DBASE Lib "mtdata.dll" (ByVal DBFileName As String, ByVal DBFileNameLen As Long, ByRef ErrMessUnit As Long, ByRef ErrFlag As Long)

'#############

Public Declare Function MT_NO_CHOSEN_DBASES Lib "mtdata.dll" () As Long
Public Declare Function MT_QUERY_CHOSEN_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long) As Long
Public Declare Sub MT_NAME_CHOSEN_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long, ByRef DBNum As Long)
Public Declare Sub MT_ADD_CHOSEN_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long, ByRef Position As Long, ByRef ErrFlag As Long)
Public Declare Sub MT_ADD_CHOSEN_DBASE_NUM Lib "mtdata.dll" (ByRef DBNum As Long, ByRef Position As Long, ByRef ErrFlag As Long)
Public Declare Sub MT_REMOVE_CHOSEN_DBASE Lib "mtdata.dll" (ByVal DBName As String, ByVal DBNameLen As Long, ByRef ErrFlag As Long)
Public Declare Sub MT_CLEAR_CHOSEN_DBASE_LIST Lib "mtdata.dll" ()
Public Declare Sub MT_SEARCH_FOR_SYSTEM Lib "mtdata.dll" (ByVal SystemName As String, ByVal SystemNameLen As Long, ByRef ErrPos As Long, ByRef ErrFlag As Long)
Public Declare Sub MT_SAVE_MPI_FILE Lib "mtdata.dll" (ByVal DataFile As String, ByVal DataFileLen As Long, ByRef ErrFlag As Long)


'############################################################
'
' Other Misc Routines

'this routine is not now exported from dll
'Public Declare Sub INITIALISE_MTDATA Lib "mtdata.dll" (ByRef imode As Long)
Public Declare Sub DEINITIALISE_MTDATA Lib "mtdata.dll" ()

' dll specific routine for other initialisation stuff, called after init_mtdata
Public Declare Function INITIALISE_MTDATA_DLL Lib "mtdata.dll" (ByRef AppCode As Long, _
                                  ByVal PrefixPath As String, ByVal PrefixPathLen As Long, _
                                  ByVal LogPath As String, ByVal LogPathLen As Long, _
                                  ByVal DatabasePath As String, ByVal DatabasePathLen As Long) As Long

Public Declare Function MOLAR_MASS Lib "mtdata.dll" (ByRef CompNum As Long) As Double
Public Declare Function GAS_CONSTANT Lib "mtdata.dll" () As Double

Public Declare Function UNDEFINED Lib "mtdata.dll" (ByRef var As Double) As Boolean
Public Declare Sub SET_TO_UNDEFINED Lib "mtdata.dll" (ByRef var As Double)

Public Declare Sub MTDATA_OPTION Lib "mtdata.dll" Alias "MTOPTN" (ByRef Dummy As Long, ByVal OptionString As String, ByVal OptionStringLen As Long)

Public Declare Sub WRITE_TO_LOG_FILE Lib "mtdata.dll" (ByVal Message As String, ByVal MessageLen As Long)
Public Declare Function LOG_FILE Lib "mtdata.dll" () As Long

Public Declare Sub AXIS_SCALE Lib "mtdata.dll" Alias "ASCALE" (ByRef XMIN As Single, _
       ByRef XMAX As Single, ByRef NXTIC As Long, _
       ByRef AMIN As Single, ByRef AMAX As Single, ByRef ATIC As Single)

Public Declare Sub LOAD_MENU Lib "mtdata.dll" Alias "SGUMEN" (ByRef MenuNumber As Long)

Public Declare Sub CPU_TIME Lib "mtdata.dll" Alias "OSCPUT" (ByRef CPUTime As Double)

Public Declare Sub MTDATA_FILE_CHECK Lib "mtdata.dll" (ByVal FileName As String, _
                                                       ByVal FileNameLen As Long, _
                                                       ByRef IStat As Long)


'############################################################
'
' Error Routines

Public Declare Function NUMBER_OF_ERRORS Lib "mtdata.dll" () As Long
Public Declare Function NUMBER_OF_WARNINGS Lib "mtdata.dll" () As Long
Public Declare Sub INIT_ERROR Lib "mtdata.dll" ()
Public Declare Sub WRITE_ERROR Lib "mtdata.dll" ()
Public Declare Sub LOG_ERROR Lib "mtdata.dll" (ByRef OutputUnit As Long)
Public Declare Function TEST_ERROR Lib "mtdata.dll" (ByRef ErrorNumber As Long) As Boolean
Public Declare Function USER_ABORT Lib "mtdata.dll" () As Boolean

'############################################################
'
' Materials Specification Routines

Public Declare Sub INITIALISE_MATERIALS Lib "mtdata.dll" (ByRef Stat As Long)
Public Declare Sub SELECT_MATERIAL Lib "mtdata.dll" (ByRef MaterialNumber As Long, ByRef Stat As Long)
Public Declare Function NO_OF_MATERIALS Lib "mtdata.dll" () As Long
Public Declare Sub MATERIAL_NAME Lib "mtdata.dll" (ByVal MaterialName As String, ByVal MaterialNameLen As Long, ByRef MaterialNumber As Long)
Public Declare Sub MATERIAL_SOURCE Lib "mtdata.dll" (ByVal MaterialSource As String, ByVal MaterialSourceLen As Long, ByRef MaterialNumber As Long)
Public Declare Sub MATERIAL_SYSTEM Lib "mtdata.dll" (ByVal MaterialSystem As String, ByVal MaterialSystemLen As Long, ByRef MaterialNumber As Long)
Public Declare Function MATERIAL_AMOUNTS Lib "mtdata.dll" (ByRef MaterialNumber As Long, ByRef ComponentNumber As Long) As Double
Public Declare Function MATERIAL_MASSES Lib "mtdata.dll" (ByRef MaterialNumber As Long, ByRef ComponentNumber As Long) As Double
Public Declare Function MATERIAL_TEMPERATURE Lib "mtdata.dll" (ByRef MaterialNumber As Long) As Double
Public Declare Function MATERIAL_PRESSURE Lib "mtdata.dll" (ByRef MaterialNumber As Long) As Double
      
